@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: sametime.c,v 1.7.2.13 2005/09/04 19:20:52 avian Exp $ */
+/* $Id: sametime.c,v 1.9 2006-02-01 20:30:05 avian Exp $ */
 
 /** @module
  *
@@ -35,6 +35,31 @@
  * This restriction specifies that current class or teacher should never have 
  * lessons at the same time as the class or teacher specified in the 
  * restriction.
+ *
+ * There are two common uses for this restriction: When multiple classes share
+ * an event and when multiple teachers share an event. Consider the following 
+ * example:
+ * 
+ * Let's say we have two groups of students. Each group has its own timetable
+ * except a couple of lessons which they share. 
+ *
+ * We define each group of students plus an extra group for the shared lessons.
+ *
+ * <resourcetype type="class">
+ *   	<resource name="Group 1">
+ *   		<restriction type="conflicts-with">Group 1+2</restriction>
+ *   	</resource>
+ *	<resource name="Group 2">
+ *   		<restriction type="conflicts-with">Group 1+2</restriction>
+ *   	</resource>
+ *	<resource name="Group 1+2"/>
+ * </resourcetype>
+ *
+ * This way group 1+2 will never have lessons at the same time as
+ * groups 1 and 2 and students from either group will be able to attend
+ * lectures in group 1+2.
+ *
+ * Multiple teachers per event can be defined in a similar way.
  */
 
 /** @option recursive-conflicts
@@ -43,9 +68,10 @@
  * "conflicts-with" restrictions become recursive.
  *
  * For example: if class A conflicts with class B and class A conflicts with 
- * class C, then class B will also automatically conflict with class C. Without
- * this option class C will not conflict with class B unless you specify this
- * with another "conflicts-with" restriction.
+ * class C, then class B will also automatically conflict with class C. 
+ *
+ * Without this option class C will not conflict with class B unless you 
+ * specify this with another "conflicts-with" restriction.
  */
 
 #ifdef HAVE_CONFIG_H
