@@ -1,5 +1,5 @@
-/* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002 Tomaz Solc                                           */
+/* TABLIX, PGA general timetable solver                                    */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: data.c,v 1.16.2.36 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: data.c,v 1.21 2006-02-04 14:16:12 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -782,11 +782,44 @@ void tuple_set(tupleinfo *tuple, resource *res)
 	tuple->resid[typeid]=resid;
 }
 
+/** @brief Compare two events.
+ *
+ * Two events are considered equal (for example, they were defined as 
+ * repeats of a single \<event\> tag), if their names are equal and if they
+ * have the same constant resources.
+ *
+ * @param tupleid1 Tuple ID of the first event.
+ * @param tupleid2 Tuple ID of the second event.
+ * @return 1 if events are equal or 0 if the are not. */
+int tuple_compare(int tupleid1, int tupleid2) 
+{
+	int n;
+
+	assert(tupleid1>=0);
+	assert(tupleid2>=0);
+
+	if(!strcmp(dat_tuplemap[tupleid1].name, dat_tuplemap[tupleid2].name)) {
+		/* Names of the tuples are equal */
+		/* Check if they are using the same constant resources */
+		for(n=0;n<dat_typenum;n++) if(!dat_restype[n].var) {
+			if(dat_tuplemap[tupleid1].resid[n]!=
+					dat_tuplemap[tupleid2].resid[n]) {
+				return 0;
+			}
+		}
+
+		return 1;
+	} 
+	return 0;
+}
+
 /** @brief Add a new tuple. 
  *
  * After the first tuple was added, any calls to restype_new() and res_new() 
  * have unspecified effects. 
  *
+ * Tuples are independent by default.
+ *
  * @param name Name of the tuple (event).
  * @return Pointer to the tupleinfo struct of the new tuple or NULL on error. */
 tupleinfo *tuple_new(char *name)
@@ -814,6 +847,7 @@ tupleinfo *tuple_new(char *name)
 	}
 
 	dest->tupleid=dat_tuplenum;
+	dest->dependent=0;
 
 	for(n=0;n<dat_typenum;n++) {
 		dest->resid[n]=INT_MIN;
