@@ -1,5 +1,5 @@
-/* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002-2005 Tomaz Solc                                      */
+/* TABLIX, PGA general timetable solver                                    */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: master.c,v 1.47.2.22 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: master.c,v 1.52 2006-02-03 18:16:03 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -50,6 +50,7 @@ char prefix[256];
 
 #ifdef HAVE_LIBPVM3
 int ctrlc;
+int timeout_reached;
 
 int numlocals;
 int maxlocals;
@@ -77,7 +78,7 @@ along with this program; if not, write to the Free Software\n\
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA\n"));
         printf("\n");
 
-        printf("$Id: master.c,v 1.47.2.22 2005/09/02 19:30:42 avian Exp $\n");
+        printf("$Id: master.c,v 1.52 2006-02-03 18:16:03 avian Exp $\n");
         printf(_("Compile time options:\n"));
         #ifdef HAVE_LIBPVM3
         printf(_("\tParallel genetic algorithm (using PVM3)\n"));
@@ -126,6 +127,9 @@ void sighandler(int num)
 {
         int c;
 
+	if(num==SIGALRM) {
+		timeout_reached=1;
+	}
         if (ctrlc<1) {
                 pvm_initsend(0);
                 c=0;
@@ -196,7 +200,7 @@ int main(int argc, char *argv[])
 	#endif
 
         printf(_("TABLIX version %s, PGA general timetable solver\n"), VERSION);
-        printf("Copyright (C) 2002-2005 Tomaz Solc\n");
+        printf("Copyright (C) 2002-2006 Tomaz Solc\n");
 
         while ((c=getopt(argc, argv, "hn:vo:rl:d:t:p:"))!=-1) {
                 switch (c) {
@@ -283,6 +287,8 @@ int main(int argc, char *argv[])
 
 	if (file_mcast(argv[optind], nodetid, nodenum, MSG_XMLDATA)) {
                 perror(cmd);
+		error(_("Failed to send problem description '%s' "
+					"to computing nodes"), argv[optind]);
                 for(c=0;c<nodenum;c++) pvm_kill(nodetid[c]);
 		free(buff);
 		free(module);
@@ -379,6 +385,7 @@ int main(int argc, char *argv[])
 	/*** Set up timer and signal handlers ***/
 
         ctrlc=0;
+	timeout_reached=0;
         signal(SIGINT, sighandler);
 	signal(SIGALRM, sighandler);
 	alarm(timeout*60);
@@ -534,13 +541,19 @@ int main(int argc, char *argv[])
         #endif
 
         if (ctrlc) {
-		info(_("interrupted."));
-	} else if(cnt_recv<1) {
-		info(_("no results were received."));
+		if(timeout_reached) {
+			error(_("Time limit reached"));
+		} else {
+			error(_("Received interrupt"));
+		}
+	} 
+	
+	if(cnt_recv<1) {
+		info(_("No results were received"));
 	} else if(cnt_recv<cnt_stopped) {
-		info(_("some results were received."));
+		info(_("Some results were received"));
 	} else {
-		info(_("all results were received."));
+		info(_("All results were received"));
 	}
 
 	if(verbosity>=MSG_INFO&&cnt_recv>0) {
