@@ -1,5 +1,5 @@
-/* TABLIX, PGA general timetable solver                              */
-/* Copyright (C) 2002-2005 Tomaz Solc                                      */
+/* TABLIX, PGA general timetable solver                                    */
+/* Copyright (C) 2002-2006 Tomaz Solc                                      */
 
 /* This program is free software; you can redistribute it and/or modify    */
 /* it under the terms of the GNU General Public License as published by    */
@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: modsup.c,v 1.14.2.18 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: modsup.c,v 1.20 2006-02-04 14:16:12 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -536,7 +536,11 @@ modulehandler *handler_find(modulehandler *cur, resourcetype *restype,
 
 	while(cur!=NULL) {
    		if(!strcmp(restriction, cur->restriction)) {
-			if(cur->restype==restype||cur->restype==&mod_anytype) {
+			if(cur->restype==restype) {
+				return(cur);
+			}
+			if(restype!=&mod_eventtype&& 
+						cur->restype==&mod_anytype) {
 				return(cur);
 			}
 		}
@@ -569,7 +573,7 @@ int handler_res_call(resource *res, char *restriction, char *content)
 	while(cur!=NULL) {
 		n=(*cur->handler_res)(restriction, content, res);
 		if(n) {
-			error(_("Restriction handler for"
+			error(_("Restriction handler for "
 				"restriction type %s failed"), restriction);
 			error(_("Resource %s, resource type %s"), 
 						res->name, res->restype->type);
@@ -601,9 +605,12 @@ int handler_tup_call(tupleinfo *tuple, char *restriction, char *content)
 	result=2;
 	cur=handler_find(mod_handler, &mod_eventtype, restriction);
 	while(cur!=NULL) {
+		assert(cur->handler_tup!=NULL);
+		assert(cur->restype==&mod_eventtype);
+
 		n=(*cur->handler_tup)(restriction, content, tuple);
 		if(n) {
-			error(_("Restriction handler for"
+			error(_("Restriction handler for "
 				"restriction type %s failed"), restriction);
 			error(_("Tuple %s"), tuple->name);
 			result=1;
