@@ -15,7 +15,7 @@
 /* along with this program; if not, write to the Free Software             */
 /* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA */
 
-/* $Id: xmlsup.c,v 1.28.2.28 2005/09/02 19:30:42 avian Exp $ */
+/* $Id: xmlsup.c,v 1.32 2006-02-03 16:33:00 avian Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -81,30 +81,23 @@ static xmlDocPtr config;
  * @param node Pointer to the XML node with error.
  */
 
-/** @brief Add an integer property to a XML node.
+#define XMLCHAR		(xmlChar *)
+
+/** @def XMLCHAR 
+ * @brief Cast to (xmlChar *)
  *
- * If a property with this name already exists it is overwritten.
+ * This macro should only be used when it is certain that the pointer
+ * contains a valid UTF-8 encoded NULL terminated string.
+ */
+
+#define CHAR		(char *)
+
+/** @def CHAR 
+ * @brief Cast to (char *)
  *
- * @param cur Pointer to the XML node.
- * @param prop Name of the property.
- * @param value Value of the property. */
-static void parser_newprop_int(xmlNodePtr cur, char *prop, int value)
-{
-	char *temp;
-
-	temp=xmlGetProp(cur, prop);
-	if(temp!=NULL) {
-		xmlUnsetProp(cur, prop);
-	}
-
-	temp=malloc(sizeof(*temp)*LINEBUFFSIZE);
-	if(temp==NULL) fatal(_("Can't allocate memory"));
-
-	snprintf(temp, LINEBUFFSIZE, "%d", value);
-	xmlNewProp(cur, prop, temp);
-
-	free(temp);
-}
+ * This macro should only be used when it is certain that the pointer 
+ * contains a valid UTF-8 encoded NULL terminated string.
+ */
 
 /** @brief Replacement for the fatal() function that adds line number to the
  * message. 
@@ -126,6 +119,31 @@ static void parser_fatal(const char *fmt, int no, ...)
 	va_end(ap);
 }
 
+/** @brief Add an integer property to a XML node.
+ *
+ * If a property with this name already exists it is overwritten.
+ *
+ * @param cur Pointer to the XML node.
+ * @param prop Name of the property.
+ * @param value Value of the property. */
+static void parser_newprop_int(xmlNodePtr cur, const xmlChar *prop, int value)
+{
+	xmlChar *temp;
+
+	temp=xmlGetProp(cur, prop);
+	if(temp!=NULL) {
+		xmlUnsetProp(cur, prop);
+	}
+	xmlFree(temp);
+
+	temp=malloc(sizeof(*temp)*LINEBUFFSIZE);
+	if(temp==NULL) fatal(_("Can't allocate memory"));
+
+	xmlStrPrintf(temp, LINEBUFFSIZE, XMLCHAR "%d", value);
+	xmlNewProp(cur, prop, temp);
+
+	free(temp);
+}
 
 /** @brief Get an integer property from a XML node.
  *
@@ -134,9 +152,9 @@ static void parser_fatal(const char *fmt, int no, ...)
  * @param cur Pointer to the XML node.
  * @param prop Name of the property. 
  * @return Content of the property. */
-static int parser_getprop_int(xmlNodePtr cur, char *prop)
+static int parser_getprop_int(xmlNodePtr cur, const xmlChar *prop)
 {
-	char *temp;
+	xmlChar *temp;
 	int n, dest;
 
 	assert(cur!=NULL);
@@ -145,10 +163,10 @@ static int parser_getprop_int(xmlNodePtr cur, char *prop)
 	temp=xmlGetProp(cur, prop);
 	if(temp==NULL) NOPROP(prop, cur);
 			
-	n=sscanf(temp, "%d", &dest);
+	n=sscanf(CHAR temp, "%d", &dest);
 	if(n!=1) INVPROP(prop, cur);
 
-	free(temp);
+	xmlFree(temp);
 
 	return(dest);
 }
@@ -159,10 +177,10 @@ static int parser_getprop_int(xmlNodePtr cur, char *prop)
  *
  * @param cur Pointer to the XML node.
  * @param prop Name of the property. 
- * @return Content of the property (must be freed afte use). */
-static char *parser_getprop_str(xmlNodePtr cur, char *prop)
+ * @return Content of the property. Must be freed with xmlFree() after use. */
+static xmlChar *parser_getprop_str(xmlNodePtr cur, const xmlChar *prop)
 {
-	char *dest;
+	xmlChar *dest;
 
 	assert(cur!=NULL);
 	assert(prop!=NULL);
@@ -180,7 +198,7 @@ static char *parser_getprop_str(xmlNodePtr cur, char *prop)
 static resource *parser_event_get_res(xmlNodePtr cur, resourcetype *restype)
 {
 	resource *res;
-	char *type, *name;
+	xmlChar *type, *name;
 	
 	assert(restype!=NULL);
 
@@ -188,16 +206,16 @@ static resource *parser_event_get_res(xmlNodePtr cur, resourcetype *restype)
 	
 	cur=cur->children;
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "resource")) {
-			type=parser_getprop_str(cur, "type");
+		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
+			type=parser_getprop_str(cur, XMLCHAR "type");
 
-			if(strcmp(type,restype->type)) {
+			if(xmlStrcmp(type, XMLCHAR restype->type)) {
 				free(type);
 				cur=cur->next;
 				continue;
 			}
 
-			name=parser_getprop_str(cur, "name");
+			name=parser_getprop_str(cur, XMLCHAR "name");
 
 			if(res!=NULL) {
 				fatal(_("Definition of event has multiple "
@@ -205,11 +223,11 @@ static resource *parser_event_get_res(xmlNodePtr cur, resourcetype *restype)
 				restype->type, xmlGetLineNo(cur));
 			}
 
-			res=res_find(restype, name);
+			res=res_find(restype, CHAR name);
 			if(res==NULL) INVPROP("name", cur);
 
-			free(type);
-			free(name);
+			xmlFree(type);
+			xmlFree(name);
 		}
 		cur=cur->next;
 	}
@@ -225,14 +243,14 @@ static void parser_event_add_res(xmlNodePtr cur, resource *res)
 {
 	xmlNodePtr resnode;
 
-        xmlNodeAddContent(cur, "\t");
+        xmlNodeAddContent(cur, XMLCHAR "\t");
 
-        resnode=xmlNewChild(cur, NULL, "resource", NULL);
+        resnode=xmlNewChild(cur, NULL, XMLCHAR "resource", NULL);
 
-        xmlNewProp(resnode, "type", res->restype->type);
-        xmlNewProp(resnode, "name", res->name);
+        xmlNewProp(resnode, XMLCHAR "type", XMLCHAR res->restype->type);
+        xmlNewProp(resnode, XMLCHAR "name", XMLCHAR res->name);
 
-        xmlNodeAddContent(cur, "\n\t\t");
+        xmlNodeAddContent(cur, XMLCHAR "\n\t\t");
 }
 
 /** @brief Parse miscellaneous information.
@@ -241,12 +259,12 @@ static void parser_event_add_res(xmlNodePtr cur, resource *res)
 static void parser_info(xmlNodePtr cur)
 {
         while (cur!=NULL) {
-                if(!strcmp(cur->name, "title")) {
-                        dat_info.title=xmlNodeGetContent(cur);
-                } else if (!strcmp(cur->name, "address")) {
-                        dat_info.address=xmlNodeGetContent(cur);
-                } else if (!strcmp(cur->name, "author")) {
-                        dat_info.author=xmlNodeGetContent(cur);
+                if(!xmlStrcmp(cur->name, XMLCHAR "title")) {
+                        dat_info.title=CHAR xmlNodeGetContent(cur);
+                } else if (!xmlStrcmp(cur->name, XMLCHAR "address")) {
+                        dat_info.address=CHAR xmlNodeGetContent(cur);
+                } else if (!xmlStrcmp(cur->name, XMLCHAR "author")) {
+                        dat_info.author=CHAR xmlNodeGetContent(cur);
                 }
                 cur=cur->next;
         }
@@ -262,20 +280,20 @@ static void parser_info(xmlNodePtr cur)
  * @param opt Pointer to the linked list of module options. */
 static moduleoption *parser_options(xmlNodePtr cur, moduleoption *opt)
 {
-	char *content, *name;
+	xmlChar *content, *name;
 	moduleoption *result;
 
 	result=opt;
 	while (cur!=NULL) {
-                if (!strcmp(cur->name, "option")) {
-			name=parser_getprop_str(cur, "name");
+                if (!xmlStrcmp(cur->name, XMLCHAR "option")) {
+			name=parser_getprop_str(cur, XMLCHAR "name");
 
 			content=xmlNodeGetContent(cur);
 
-			result=option_new(result, name, content);
+			result=option_new(result, CHAR name, CHAR content);
 
-			free(name);
-			free(content);
+			xmlFree(name);
+			xmlFree(content);
                 }
                 cur=cur->next;
         }
@@ -288,21 +306,21 @@ static moduleoption *parser_options(xmlNodePtr cur, moduleoption *opt)
  * @param cur Pointer to the \<modules\> node. */
 static void parser_modules(xmlNodePtr cur)
 {
-        char *name, *weight, *mandatory;
+        xmlChar *name, *weight, *mandatory;
 	moduleoption *opt;
 	module *dest;
 
         while(cur!=NULL) {
-                  if (!strcmp(cur->name, "module")) {
-                        name=parser_getprop_str(cur, "name");
-			weight=parser_getprop_str(cur, "weight");
-			mandatory=parser_getprop_str(cur, "mandatory");
+                  if (!xmlStrcmp(cur->name, XMLCHAR "module")) {
+                        name=parser_getprop_str(cur, XMLCHAR "name");
+			weight=parser_getprop_str(cur, XMLCHAR "weight");
+			mandatory=parser_getprop_str(cur, XMLCHAR "mandatory");
 
-			opt=option_new(NULL, "weight", weight);
+			opt=option_new(NULL, "weight", CHAR weight);
 
-			if(!strcmp(mandatory, "yes")) {
+			if(!xmlStrcmp(mandatory, XMLCHAR "yes")) {
 				opt=option_new(opt, "mandatory", "1");
-			} else if(!strcmp(mandatory, "no")) {
+			} else if(!xmlStrcmp(mandatory, XMLCHAR "no")) {
 				opt=option_new(opt, "mandatory", "0");
 			} else {
 				FAIL("Property 'mandatory' should be 'yes'"
@@ -311,14 +329,14 @@ static void parser_modules(xmlNodePtr cur)
 
 			opt=parser_options(cur->children, opt);
 
-			dest=module_load(name,opt);
+			dest=module_load(CHAR name, opt);
 			if(dest==NULL) {
 				fatal(_("Module %s failed to load"), name);
 			} 
 
-                        free(name);
-			free(weight);
-			free(mandatory);
+                        xmlFree(name);
+			xmlFree(weight);
+			xmlFree(mandatory);
 
 			option_free(opt);
                 } 
@@ -336,16 +354,18 @@ static void parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
 {
 	int n;
 	int result;
-	char *restriction;
-	char *content;
+	xmlChar *restriction;
+	xmlChar *content;
+
         while(cur!=NULL) {
-                if(!strcmp(cur->name, "restriction")) {
-			restriction=parser_getprop_str(cur, "type");
+                if(!xmlStrcmp(cur->name, XMLCHAR "restriction")) {
+			restriction=parser_getprop_str(cur, XMLCHAR "type");
 			content=xmlNodeGetContent(cur);
 
 			for(n=tupleid;n<tupleid+repeats;n++) {
 				result=handler_tup_call(&dat_tuplemap[n],
-							restriction,content);
+							CHAR restriction,
+							CHAR content);
 				if(result==1) {
 					FAIL("Restriction handler failed", cur);
 				} else if(result==2) {
@@ -355,8 +375,8 @@ static void parser_event_restrictions(xmlNodePtr cur, int tupleid, int repeats)
 				}
 			}
 
-                        free(restriction);
-			free(content);
+                        xmlFree(restriction);
+			xmlFree(content);
                 }
                 cur=cur->next;
         }
@@ -371,9 +391,9 @@ static void parser_events_restrictions(xmlNodePtr cur)
 	int tupleid;
 
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "event")) {
-			tupleid=parser_getprop_int(cur, "tupleid");
-			repeats=parser_getprop_int(cur, "repeats");
+		if(!xmlStrcmp(cur->name, XMLCHAR "event")) {
+			tupleid=parser_getprop_int(cur, XMLCHAR "tupleid");
+			repeats=parser_getprop_int(cur, XMLCHAR "repeats");
 	
 			parser_event_restrictions(cur->children, 
 							tupleid, repeats);
@@ -391,7 +411,7 @@ static void parser_event(xmlNodePtr start, tupleinfo *tuple)
 {
 	resource *res;
 	resourcetype *restype;
-	char *type;
+	xmlChar *type;
 	int n;
 
 	xmlNodePtr cur;
@@ -400,13 +420,13 @@ static void parser_event(xmlNodePtr start, tupleinfo *tuple)
 
 	cur=start;
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "resource")) {
-			type=parser_getprop_str(cur, "type");
+		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
+			type=parser_getprop_str(cur, XMLCHAR "type");
 
-			restype=restype_find(type);
+			restype=restype_find(CHAR type);
 			if(restype==NULL) INVPROP("type", cur);
 
-			free(type);
+			xmlFree(type);
 		}
 		cur=cur->next;
 	}
@@ -429,20 +449,20 @@ static void parser_event(xmlNodePtr start, tupleinfo *tuple)
  * @param cur Pointer to the \<events\> node. */
 static void parser_events(xmlNodePtr cur)
 {
-	char *name;
+	xmlChar *name;
 	int repeats;
 	tupleinfo *dest=NULL;
 	int n;
 
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "event")) {
-			name=parser_getprop_str(cur, "name");
+		if(!xmlStrcmp(cur->name, XMLCHAR "event")) {
+			name=parser_getprop_str(cur, XMLCHAR "name");
 
-			repeats=parser_getprop_int(cur, "repeats");
+			repeats=parser_getprop_int(cur, XMLCHAR "repeats");
 			if (repeats<=0) INVPROP("repeats", cur);
 
 			for(n=0;n<repeats;n++) {
-				dest=tuple_new(name);
+				dest=tuple_new(CHAR name);
 				if(dest==NULL) {
 					fatal(_("Can't allocate memory"));
 				}
@@ -450,10 +470,10 @@ static void parser_events(xmlNodePtr cur)
 				parser_event(cur->children, dest);
 			}
 
-			parser_newprop_int(cur, "tupleid", 
+			parser_newprop_int(cur, XMLCHAR "tupleid", 
 						dest->tupleid-repeats+1); 
 
-			free(name);
+			xmlFree(name);
 		}
 		cur=cur->next;
 	}
@@ -465,23 +485,24 @@ static void parser_events(xmlNodePtr cur)
  * @param res Pointer to the resource struct for this resource. */
 static void parser_resource_restrictions_one(xmlNodePtr cur, resource *res) 
 {
-	char *restriction, *content;
+	xmlChar *restriction, *content;
 	int result;
 	
 	while (cur!=NULL) {
-		if(!strcmp(cur->name, "restriction")) {
-			restriction=parser_getprop_str(cur, "type");
+		if(!xmlStrcmp(cur->name, XMLCHAR "restriction")) {
+			restriction=parser_getprop_str(cur, XMLCHAR "type");
 			content=xmlNodeGetContent(cur);
 
-			result=handler_res_call(res, restriction, content);
+			result=handler_res_call(res, CHAR restriction, 
+								CHAR content);
 
 			if(result==1) FAIL("Restriction handler failed", cur);
 			if(result==2) info(_("Unknown resource restriction '%s'"
 						"(line %d)"), restriction, 
 						xmlGetLineNo(cur));
 
-			free(restriction);
-			free(content);
+			xmlFree(restriction);
+			xmlFree(content);
 		}
 		cur=cur->next;
 	}
@@ -499,15 +520,16 @@ static void parser_resource_restrictions(xmlNodePtr cur, resourcetype *restype)
 	int resid1, resid2;
 
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "resource")) {
-                        resid=parser_getprop_int(cur, "resid");
+		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
+                        resid=parser_getprop_int(cur, XMLCHAR "resid");
 
 			res=&restype->res[resid];
 			parser_resource_restrictions_one(cur->children, res);
-                } else if((!strcmp(cur->name, "linear"))||
-					(!strcmp(cur->name, "matrix"))) {
-			resid1=parser_getprop_int(cur, "resid-from");
-			resid2=parser_getprop_int(cur, "resid-to");
+                } else if((!xmlStrcmp(cur->name, XMLCHAR "linear"))||
+				(!xmlStrcmp(cur->name, XMLCHAR "matrix"))) {
+
+			resid1=parser_getprop_int(cur, XMLCHAR "resid-from");
+			resid2=parser_getprop_int(cur, XMLCHAR "resid-to");
 
 			for(n=resid1;n<=resid2;n++) {
 				res=&restype->res[n];
@@ -526,14 +548,18 @@ static void parser_resources_restrictions(xmlNodePtr cur)
 {
 	xmlNodePtr res;
 	int typeid;
+
         while(cur!=NULL) {
-                if ((!strcmp(cur->name, "constant"))||
-					(!strcmp(cur->name, "variable"))) {
+                if ((!xmlStrcmp(cur->name, XMLCHAR "constant"))||
+				(!xmlStrcmp(cur->name, XMLCHAR "variable"))) {
+
 			res=cur->children;
 			while(res!=NULL) {
-				if(!strcmp(res->name, "resourcetype")) {
+				if(!xmlStrcmp(res->name, 
+						XMLCHAR "resourcetype")) {
+
 					typeid=parser_getprop_int(
-							res, "typeid");
+							res, XMLCHAR "typeid");
 
 					parser_resource_restrictions(
 							res->children, 
@@ -552,38 +578,40 @@ static void parser_resources_restrictions(xmlNodePtr cur)
  * @param restype Pointer to the resource type struct for this resource type. */
 static void parser_resource(xmlNodePtr cur, resourcetype *restype)
 {
-	char *name, *prefix, *postfix, *fullname;
+	xmlChar *name, *fullname;
+	char *postfix, *prefix;
 	int from, to;
 	int width, height;
 	int n;
 	resource *dest;
 
 	while(cur!=NULL) {
-		if(!strcmp(cur->name, "resource")) {
-                        name=parser_getprop_str(cur, "name");
+		if(!xmlStrcmp(cur->name, XMLCHAR "resource")) {
+                        name=parser_getprop_str(cur, XMLCHAR "name");
 
-                        dest=res_find(restype, name);
+                        dest=res_find(restype, CHAR name);
                         if(dest==NULL) {
-				dest=res_new(restype, name);
+				dest=res_new(restype, CHAR name);
 				if(dest==NULL) {
 					fatal(_("Can't allocate memory"));
 				}
-				parser_newprop_int(cur, "resid", dest->resid);
+				parser_newprop_int(cur, XMLCHAR "resid", 
+								dest->resid);
 			} else {
 				FAIL("Resource already defined", cur);
 			}
 
-			free(name);
-                } else if(!strcmp(cur->name, "linear")) {
-                        name=parser_getprop_str(cur, "name");
-			from=parser_getprop_int(cur, "from");
-			to=parser_getprop_int(cur, "to");
+			xmlFree(name);
+                } else if(!xmlStrcmp(cur->name, XMLCHAR "linear")) {
+                        name=parser_getprop_str(cur, XMLCHAR "name");
+			from=parser_getprop_int(cur, XMLCHAR "from");
+			to=parser_getprop_int(cur, XMLCHAR "to");
 
-			if(from>to) FAIL("Value in 'from' property must be"
-					"smaller than the value in 'to'"
+			if(from>to) FAIL("Value in 'from' property must be "
+					"smaller than the value in 'to' "
 					"property", cur);
 
-			postfix=name;
+			postfix=CHAR name;
 			prefix=strsep(&postfix, "#");
 			if(postfix==NULL) {
 				FAIL("'name' property must contain '#'", cur);
@@ -593,30 +621,32 @@ static void parser_resource(xmlNodePtr cur, resourcetype *restype)
 			if(fullname==NULL) fatal(_("Can't allocate memory"));
 
 			for(n=from;n<=to;n++) {
-				snprintf(fullname, LINEBUFFSIZE, "%s%d%s", 
+				xmlStrPrintf(fullname, LINEBUFFSIZE, 
+							XMLCHAR "%s%d%s", 
 							prefix, n, postfix);
 
-				dest=res_new(restype, fullname);
+				dest=res_new(restype, CHAR fullname);
 				if(dest==NULL) {
 					fatal(_("Can't allocate memory"));
 				}
 				if(n==from) {
-					parser_newprop_int(cur, "resid-from", 
-								dest->resid);
+					parser_newprop_int(cur, 
+							XMLCHAR "resid-from", 
+							dest->resid);
 				} else if(n==to) {
-					parser_newprop_int(cur, "resid-to", 
-								dest->resid);
+					parser_newprop_int(cur, 
+							XMLCHAR "resid-to", 
+							dest->resid);
 				}
 			}
 
-
 			free(fullname);
-			free(name);
-                } else if(!strcmp(cur->name, "matrix")) {
-			width=parser_getprop_int(cur, "width");
+			xmlFree(name);
+                } else if(!xmlStrcmp(cur->name, XMLCHAR "matrix")) {
+			width=parser_getprop_int(cur, XMLCHAR "width");
 			if(width<=0) INVPROP("width", cur);
 
-			height=parser_getprop_int(cur, "height");
+			height=parser_getprop_int(cur, XMLCHAR "height");
 			if(height<=0) INVPROP("height", cur);
 
 			dest=res_new_matrix(restype, width, height);
@@ -625,9 +655,10 @@ static void parser_resource(xmlNodePtr cur, resourcetype *restype)
 				fatal(_("Can't allocate memory"));
 			}
 
-			parser_newprop_int(cur, "resid-from", 
+			parser_newprop_int(cur, XMLCHAR "resid-from", 
 						dest->resid-(height*width)+1);
-			parser_newprop_int(cur, "resid-to", dest->resid);
+			parser_newprop_int(cur, XMLCHAR "resid-to", 
+								dest->resid);
 		}
 		cur=cur->next;
 	}
@@ -639,20 +670,20 @@ static void parser_resource(xmlNodePtr cur, resourcetype *restype)
  * @param var Set to 1 if this node is under \<variable\> node. */
 static void parser_restype(xmlNodePtr cur, int var)
 {
-	char *type;
+	xmlChar *type;
 	resourcetype *dest;
 
-	type=xmlGetProp(cur, "type");
+	type=xmlGetProp(cur, XMLCHAR "type");
 	if(type==NULL) NOPROP("type", cur);
 
-	dest=restype_new(var, type);
+	dest=restype_new(var, CHAR type);
 	if(dest==NULL) {
 		fatal(_("Can't allocate memory"));
 	}
 
-	parser_newprop_int(cur, "typeid", dest->typeid);
+	parser_newprop_int(cur, XMLCHAR "typeid", dest->typeid);
 
-	free(type);
+	xmlFree(type);
 }
 
 /** @brief Parse all resource types.
@@ -666,18 +697,22 @@ static void parser_resources(xmlNodePtr start)
 
 	cur=start;
         while(cur!=NULL) {
-                if (!strcmp(cur->name, "constant")) {
+                if (!xmlStrcmp(cur->name, XMLCHAR "constant")) {
 			res=cur->children;
 			while(res!=NULL) {
-				if(!strcmp(res->name, "resourcetype")) {
+				if(!xmlStrcmp(res->name, 
+						XMLCHAR "resourcetype")) {
+
 					parser_restype(res, 0);
 				}
 				res=res->next;
 			}
-                } else if (!strcmp(cur->name, "variable")) {
+                } else if (!xmlStrcmp(cur->name, XMLCHAR "variable")) {
 			res=cur->children;
 			while(res!=NULL) {
-				if(!strcmp(res->name, "resourcetype")) {
+				if(!xmlStrcmp(res->name, 
+						XMLCHAR "resourcetype")) {
+
 					parser_restype(res, 1);
 				}
 				res=res->next;
@@ -688,12 +723,16 @@ static void parser_resources(xmlNodePtr start)
 
 	cur=start;
         while(cur!=NULL) {
-                if (!strcmp(cur->name, "constant")||
-					!strcmp(cur->name, "variable")) {
+                if (!xmlStrcmp(cur->name, XMLCHAR "constant")||
+				!xmlStrcmp(cur->name, XMLCHAR "variable")) {
+
 			res=cur->children;
 			while(res!=NULL) {
-				if(!strcmp(res->name, "resourcetype")) {
-					typeid=parser_getprop_int(res, "typeid");
+				if(!xmlStrcmp(res->name, 
+						XMLCHAR "resourcetype")) {
+
+					typeid=parser_getprop_int(res, 
+							XMLCHAR "typeid");
 					parser_resource(res->children, 
 							&dat_restype[typeid]);
 				}
@@ -757,23 +796,25 @@ static void parser_libxml_init(char *filename)
  * @param root Pointer to the root node of the XML tree. */
 static void parser_version_check(xmlNodePtr root)
 {
-	char *version;
+	xmlChar *version;
 
-        if(strcmp(root->name, "ttm")) {
-		if(!strcmp(root->name, "school")) {
+        if(xmlStrcmp(root->name, XMLCHAR "ttm")) {
+		if(!xmlStrcmp(root->name, XMLCHAR "school")) {
 			error("Configuration files from Tablix versions "
 					"prior to 0.2.1 are not supported");
 		}
                 FAIL("Root XML element is not 'ttm'", root);
         }
 
-        version=xmlGetProp(root, "version");
+        version=xmlGetProp(root, XMLCHAR "version");
 	if(version==NULL) {
 		NOPROP("version", root);
 	}
-	if(strcmp(version, PARSER_TTM_VERSION)) {
+	if(xmlStrcmp(version, XMLCHAR PARSER_TTM_VERSION)) {
 		FAIL("Configuration file has incompatible TTM version", root);
 	}
+
+	xmlFree(version);
 }
 
 /** @brief Parses an XML configuration file.
@@ -809,13 +850,13 @@ int parser_main(char *filename)
 	cur=cur->children;
 
         while (cur!=NULL) {
-                if(!strcmp(cur->name, "info")) {
+                if(!xmlStrcmp(cur->name,XMLCHAR "info")) {
                         info=cur->children;
-                } else if(!strcmp(cur->name, "resources")) {
+                } else if(!xmlStrcmp(cur->name,XMLCHAR "resources")) {
                         resources=cur->children;
-                } else if(!strcmp(cur->name, "events")) {
+                } else if(!xmlStrcmp(cur->name,XMLCHAR "events")) {
                         events=cur->children;
-                } else if(!strcmp(cur->name, "modules")) {
+                } else if(!xmlStrcmp(cur->name,XMLCHAR "modules")) {
                         modules=cur->children;
                 }
 
@@ -857,7 +898,7 @@ int parser_main(char *filename)
  * @param cur Pointer to the \<event\> node in the XML tree. */
 static void parser_clean(xmlNodePtr cur)
 {
-	char *type;
+	xmlChar *type;
 	resourcetype *restype;
 	xmlNodePtr next;
 	
@@ -866,9 +907,9 @@ static void parser_clean(xmlNodePtr cur)
 	cur=cur->children;
 	while(cur!=NULL) {
 		next=cur->next;
-                if (!strcmp(cur->name, "resource")) {
-			type=parser_getprop_str(cur, "type");
-			restype=restype_find(type);
+                if (!xmlStrcmp(cur->name, XMLCHAR "resource")) {
+			type=parser_getprop_str(cur, XMLCHAR "type");
+			restype=restype_find(CHAR type);
 
 			assert(restype!=NULL);
 
@@ -876,6 +917,8 @@ static void parser_clean(xmlNodePtr cur)
 				xmlUnlinkNode(cur);
 				xmlFreeNode(cur);
 			}
+
+			xmlFree(type);
 		}
 		cur=next;
 	}
@@ -892,15 +935,16 @@ static void parser_remove_repeats(xmlNodePtr cur)
 	xmlNodePtr copy;
 
 	while(cur!=NULL) {
-                if (!strcmp(cur->name, "event")) {
-			repeats=parser_getprop_int(cur, "repeats");
-			tupleid=parser_getprop_int(cur, "tupleid");
+                if (!xmlStrcmp(cur->name, XMLCHAR "event")) {
+			repeats=parser_getprop_int(cur, XMLCHAR "repeats");
+			tupleid=parser_getprop_int(cur, XMLCHAR "tupleid");
 			if(repeats>1) {
-				xmlSetProp(cur, "repeats", "1");
+				xmlSetProp(cur, XMLCHAR "repeats", XMLCHAR "1");
 				for(n=repeats-1;n>0;n--) {
 					copy=xmlCopyNode(cur, 1);
-					parser_newprop_int(copy, "tupleid", 
-								tupleid+n);
+					parser_newprop_int(copy, 
+							XMLCHAR "tupleid", 
+							tupleid+n);
 					xmlAddNextSibling(cur, copy);
 				}
 			}
@@ -922,7 +966,7 @@ void parser_gettable(table *tab)
 	int fitness;
 	int n;
 
-	char *temp;
+	xmlChar *temp;
 
 	resourcetype *restype;
 	resource *res;
@@ -931,15 +975,15 @@ void parser_gettable(table *tab)
 
         root=xmlDocGetRootElement(config);
 
-	temp=xmlGetProp(root, "fitness");
+	temp=xmlGetProp(root, XMLCHAR "fitness");
 	if(temp==NULL) error(_("This file does not seem to contain a solution"));
-	free(temp);
+	xmlFree(temp);
 	
-	fitness=parser_getprop_int(root, "fitness");
+	fitness=parser_getprop_int(root, XMLCHAR "fitness");
 
         cur=root->children;
         while (cur!=NULL) {
-                if (!strcmp(cur->name, "events")) events=cur;
+                if (!xmlStrcmp(cur->name, XMLCHAR "events")) events=cur;
                 cur=cur->next;
         }
 
@@ -947,12 +991,12 @@ void parser_gettable(table *tab)
 
         cur=events->children;
         while (cur!=NULL) {
-                if (!strcmp(cur->name, "event")) {
-			tupleid=parser_getprop_int(cur, "tupleid");
-			repeats=parser_getprop_int(cur, "repeats");
+                if (!xmlStrcmp(cur->name, XMLCHAR "event")) {
+			tupleid=parser_getprop_int(cur, XMLCHAR "tupleid");
+			repeats=parser_getprop_int(cur, XMLCHAR "repeats");
 
 			if(repeats!=1) {
-				fatal(_("Configuration file does not contain"
+				fatal(_("Configuration file does not contain "
 					"a complete solution"));
 			}
 
@@ -964,7 +1008,7 @@ void parser_gettable(table *tab)
 				res=parser_event_get_res(cur, restype);
 
 				if(res==NULL) {	
-					fatal(_("Configuration file does not"
+					fatal(_("Configuration file does not "
 						"contain a complete solution"));
 				}
 
@@ -998,11 +1042,11 @@ void parser_addtable(table *tab)
 
         root=xmlDocGetRootElement(config);
 
-	parser_newprop_int(root, "fitness", tab->fitness);
+	parser_newprop_int(root, XMLCHAR "fitness", tab->fitness);
 
         cur=root->children;
         while(cur!=NULL) {
-                if (!strcmp(cur->name, "events")) events=cur;
+                if (!xmlStrcmp(cur->name, XMLCHAR "events")) events=cur;
                 cur=cur->next;
         }
 
@@ -1012,10 +1056,10 @@ void parser_addtable(table *tab)
 
 	cur=events->children;
 	while(cur!=NULL) {
-                if (!strcmp(cur->name, "event")) {
+                if (!xmlStrcmp(cur->name, XMLCHAR "event")) {
 			parser_clean(cur);
-			tupleid=parser_getprop_int(cur, "tupleid");
-			assert(parser_getprop_int(cur, "repeats")==1);
+			tupleid=parser_getprop_int(cur, XMLCHAR "tupleid");
+			assert(parser_getprop_int(cur, XMLCHAR "repeats")==1);
 
 			for(n=0;n<dat_typenum;n++) {
 				restype=&dat_restype[n];
